geo_turf v0.1.0 Geo.Turf

Geo.Turf

A spatial analysis tool for Elixir's Geo library ported from TurfJS.

Installation

At the moment the library is in early development mode. The API could, and propably will, change on any moment.

def deps do
  [
    {:geo_turf, "~> 0.1"}
  ]
end

Usage

The library can perform functions on Geo objects as well as basic mathematic functions useful in spatial analysis. At the moment Geo.Turf expects WGS84 coordinates.

For example:

Suggestions

If there are functions you need from TurfJS or just things you thought of please just make an issue for it. Including a test for it would be great.

Link to this section Summary

Link to this section Types

Link to this type

coordinates()
coordinates() :: {Number.t(), Number.t()}